==> haskell-warp-tls-3.2.0-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-warp-tls/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.0
id: warp-tls-3.2.0-54fa63193f03b09ad529060d71c5191e
key: warpt_JUPB94iBoEaFKn83kx8GZl
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    Support for SSL is now obsoleted.
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-tls-3.2.0
hs-libraries: HSwarp-tls-3.2.0-JUPB94iBoEaFKn83kx8GZl
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cprng-aes-0.6.1-4f88e976d4e99640259c02d6940382c2
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    streaming-commons-0.1.15-43ddfb983feecf5e5c9c7ab99b5e44ed
    tls-1.3.4-c263a34393f014f88bd2eb81ef38f476
    wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
    warp-3.2.1-184b585d1fe25e67a905eacad9ccd211
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-warp-tls/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.1
id: warp-tls-3.2.1-4d202b26f63cb34cdcb258e59f591b80
key: warpt_GEIfLMd2B7m4VsBbKlskkZ
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    Support for SSL is now obsoleted.
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-tls-3.2.1
hs-libraries: HSwarp-tls-3.2.1-GEIfLMd2B7m4VsBbKlskkZ
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
    tls-1.3.4-c1ffd726a31a364e53d7dbf7360c4f21
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    warp-3.2.3-e779983be81de2d2755ab5db7108dace
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
